@@ -54,15 +54,24 @@ warnings.filterwarnings(
     "ignore",
     message=" WARN: Box bound precision lowered by casting to float32",
 )
-try:
-    from plangym.atari import AtariEnvironment  # noqa: E402
-except ImportError as e:
-    warnings.warn("Failed to import module in plangym.__init__.py: %s" % str(e))
+warnings.filterwarnings(
+    "ignore",
+    message=(
+        " DeprecationWarning: The binary mode of fromstring is deprecated, "
+        "as it behaves surprisingly on unicode inputs. Use frombuffer instead"
+    ),
+)
+
+
+from plangym.atari import AtariEnvironment  # noqa: E402
+from plangym.box_2d import Box2DEnv, LunarLander  # noqa: E402
 from plangym.classic_control import ClassicControl  # noqa: E402
 from plangym.core import BaseEnvironment  # noqa: E402
 from plangym.dm_control import DMControlEnv  # noqa: E402
 from plangym.minimal import MinimalPacman, MinimalPong  # noqa: E402
 from plangym.montezuma import Montezuma  # noqa: E402
 from plangym.parallel import ParallelEnvironment  # noqa: E402
+from plangym.ray import RayEnv  # noqa: E402
+from plangym.registry import make  # noqa: E402
 from plangym.retro import RetroEnvironment  # noqa: E402
 from plangym.version import __version__  # noqa: E402
